summaryrefslogtreecommitdiff
path: root/include/bluetooth_le.h
diff options
context:
space:
mode:
authorPaul Fagerburg <pfagerburg@google.com>2020-07-27 15:52:15 -0600
committerCommit Bot <commit-bot@chromium.org>2020-07-28 22:59:41 +0000
commit6efabc79d3519baa56ba1c065035a491fc6918ec (patch)
tree9981d7bbdc897ef485226c8f13000c4a2ef83403 /include/bluetooth_le.h
parent63498074bd3a77b28d2a96ef43aeceed51aa2bde (diff)
downloadchrome-ec-6efabc79d3519baa56ba1c065035a491fc6918ec.tar.gz
ec: change usage of whitelist/blacklist
Google is working to change its source code to use more inclusive language. To that end, replace the terms "whitelist", "blacklist", and similar with inclusive alternatives. BUG=b:162262297 BRANCH=None TEST=`grep -Eirl "(white|black)[ _\-]*list" .` The only results are in "private/nordic_keyboard/sdk8.0.0" which is not our code. Signed-off-by: Paul Fagerburg <pfagerburg@google.com> Change-Id: Ie5210b98e1096c22d0e9284c101a42820bd3d79d Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2321549 Tested-by: Paul Fagerburg <pfagerburg@chromium.org> Reviewed-by: Jett Rink <jettrink@chromium.org> Commit-Queue: Paul Fagerburg <pfagerburg@chromium.org>
Diffstat (limited to 'include/bluetooth_le.h')
-rw-r--r--include/bluetooth_le.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/include/bluetooth_le.h b/include/bluetooth_le.h
index 1842b57adc..286653dda6 100644
--- a/include/bluetooth_le.h
+++ b/include/bluetooth_le.h
@@ -382,11 +382,11 @@ void dump_ble_addr(uint8_t *mem, char *name);
void dump_ble_packet(struct ble_pdu *ble_p);
-/* Radio-specific white list handling */
-int ble_radio_clear_white_list(void);
-int ble_radio_read_white_list_size(uint8_t *ret_size);
-int ble_radio_add_device_to_white_list(const uint8_t *addr_ptr, uint8_t rand);
-int ble_radio_remove_device_from_white_list(const uint8_t *addr_ptr,
+/* Radio-specific allow list handling */
+int ble_radio_clear_allow_list(void);
+int ble_radio_read_allow_list_size(uint8_t *ret_size);
+int ble_radio_add_device_to_allow_list(const uint8_t *addr_ptr, uint8_t rand);
+int ble_radio_remove_device_from_allow_list(const uint8_t *addr_ptr,
uint8_t rand);
#endif /* __CROS_EC_BLE_H */